'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = copyIndexPHPFilesFromNodeModules;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _nodeFsExtra = require('node-fs-extra');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Get all subdirectories in a passed-in directory.
 * @param  {string} srcpath The path of the directory to search.
 * @return {array}         The subdirectories.
 */
function getDirectories(srcpath) {
  return _fs2.default.readdirSync(srcpath).filter(function (file) {
    return _fs2.default.statSync(_path2.default.join(srcpath, file)).isDirectory();
  });
}

/**
 * If an index.php file exists, copies it to current project, changing its name
 * to its node_modules directory name.
 * @param  {string} PHPfilename The file path.
 */
function maybeCopyIndexPHP(PHPfilename, directory) {
  if (_fs2.default.existsSync(PHPfilename)) {
    _fs2.default.createReadStream(PHPfilename).pipe(_fs2.default.createWriteStream(process.env.PWD + '/wp-autoload/from-node/' + directory + '.php'));
  }
}

/**
 * If the node_modules directory has subdirectories, starting with `wp-`, copy
 * them into the current project.
 * @param  {string} directoryPath Path to the module directory.
 */
function maybeCopyNecessarySubdirectories(directoryPath) {
  var subdirectories = getDirectories(directoryPath);

  subdirectories.forEach(function (subdirectory) {
    if (subdirectory.indexOf('wp-') === 0) {
      (0, _nodeFsExtra.copySync)('' + directoryPath + subdirectory, process.env.PWD + '/wp-autoload/from-node/' + subdirectory);
    }
  });
}

/**
 * Checks the contents of a directory and possibly copy files/folders into the
 * root directory.
 * @param  {string} directory The directory to check.
 */
function maybeCopyFromDirectory(directory) {
  var directoryPath = process.env.PWD + '/node_modules/' + directory + '/';
  var PHPfilename = _path2.default.normalize(directoryPath + 'index.php');

  maybeCopyIndexPHP(PHPfilename, directory);
  maybeCopyNecessarySubdirectories(directoryPath);
}

/**
 * Runs the script.
 */
function copyIndexPHPFilesFromNodeModules() {
  var directories = getDirectories(_path2.default.normalize(process.env.PWD + '/node_modules'));

  if (!directories) {
    return;
  }

  directories.forEach(maybeCopyFromDirectory);
}